@@ -1,17 +1,13 @@
 package Games::Tournament::Swiss::Procedure;
-BEGIN {
-  $Games::Tournament::Swiss::Procedure::VERSION = '0.18';
-}
-
-# Last Edit: 2010 12月 04, 15時35分12秒
+$Games::Tournament::Swiss::Procedure::VERSION = '0.20';
+# Last Edit: 2011  2月 27, 21時17分29秒
 # $Id: $
 
 use warnings;
 use strict;
 
 # use Games::Tournament::Swiss::Config;
-use constant ALGORITHM => $Games::Tournament::Swiss::Config::algorithm;
-use base qq/$Games::Tournament::Swiss::Config::algorithm/;
+use base $Games::Tournament::Swiss::Config::algorithm;
 
 
 =head1 NAME
